FieldManager class
Manages the backing field data for an instance of the BindableBase class.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getGenericValue<
T> (PropertyInfo propertyInfo) → T -
getValue(
PropertyInfo propertyInfo) → Object? - Get's the value for a property info on a class instance.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setGenericValue<
T> (PropertyInfo propertyInfo, T value) → void -
setValue(
PropertyInfo propertyInfo, Object? value) → void - Set's a new value for a property info on a class instance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited